# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetNlbSecurityPolicyResult',
    'AwaitableGetNlbSecurityPolicyResult',
    'get_nlb_security_policy',
    'get_nlb_security_policy_output',
]

@pulumi.output_type
class GetNlbSecurityPolicyResult:
    """
    A collection of values returned by getNlbSecurityPolicy.
    """
    def __init__(__self__, account_id=None, ciphers=None, created_time=None, id=None, project_name=None, related_listener_ids=None, security_policy_id=None, security_policy_name=None, status=None, tags=None, tls_versions=None, updated_time=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if ciphers and not isinstance(ciphers, list):
            raise TypeError("Expected argument 'ciphers' to be a list")
        pulumi.set(__self__, "ciphers", ciphers)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if related_listener_ids and not isinstance(related_listener_ids, list):
            raise TypeError("Expected argument 'related_listener_ids' to be a list")
        pulumi.set(__self__, "related_listener_ids", related_listener_ids)
        if security_policy_id and not isinstance(security_policy_id, str):
            raise TypeError("Expected argument 'security_policy_id' to be a str")
        pulumi.set(__self__, "security_policy_id", security_policy_id)
        if security_policy_name and not isinstance(security_policy_name, str):
            raise TypeError("Expected argument 'security_policy_name' to be a str")
        pulumi.set(__self__, "security_policy_name", security_policy_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if tls_versions and not isinstance(tls_versions, list):
            raise TypeError("Expected argument 'tls_versions' to be a list")
        pulumi.set(__self__, "tls_versions", tls_versions)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> builtins.str:
        """
        TLS 安全策略所属的账号ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter
    def ciphers(self) -> Sequence[builtins.str]:
        """
        TLS自定义安全策略的加密套件，不同的TLS协议版本支持的加密套件如下：TLSv1.0 & TLSv1.1：ECDHE-ECDSA-AES128-SHA，ECDHE-ECDSA-AES256-SHA，ECDHE-RSA-AES128-SHA，ECDHE-RSA-AES256-SHA，AES128-SHA，AES256-SHA，DES-CBC3-SHA。TLSv1.2：ECDHE-ECDSA-AES128-GCM-SHA256，ECDHE-ECDSA-AES256-GCM-SHA384，ECDHE-ECDSA-AES128-SHA256，ECDHE-ECDSA-AES256-SHA384，ECDHE-RSA-AES128-GCM-SHA256，ECDHE-RSA-AES256-GCM-SHA384，ECDHE-RSA-AES128-SHA256，ECDHE-RSA-AES256-SHA384，AES128-GCM-SHA256，AES256-GCM-SHA384，AES128-SHA256，AES256-SHA256。TLSv1.3：TLS*CHACHA20*POLY1305*SHA256，TLS*AES*256*GCM*SHA384，TLS*AES*128*GCM*SHA256，TLS*AES*128*CCM*8*SHA256，TLS*AES*128*CCM*SHA256，TLS*SM4*GCM*SM3，TLS*SM4*CCM*SM3。当传入此参数时，需要传入待支持的全部加密套件，不支持通过此接口仅新增/删除加密套件。仅传入Ciphers.N，未传入TlsVersions.N，则依据当前监听器支持的TLS 协议版本和请求中传入的加密套件做校验。传入TlsVersions.N和Ciphers.N，则依据请求中传入的TLS 协议版本和加密套件做校验。TLS*SM4*GCM*SM3和TLS*SM4*CCM*SM3两个加密套件正在邀测中，如需试用，请联系客户经理。
        """
        return pulumi.get(self, "ciphers")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        TLS自定义安全策略所属项目的名称。不传则默认为defaul。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="relatedListenerIds")
    def related_listener_ids(self) -> Sequence[builtins.str]:
        """
        TLS 安全策略关联的监听器。
        """
        return pulumi.get(self, "related_listener_ids")

    @property
    @pulumi.getter(name="securityPolicyId")
    def security_policy_id(self) -> builtins.str:
        """
        安全策略ID。
        """
        return pulumi.get(self, "security_policy_id")

    @property
    @pulumi.getter(name="securityPolicyName")
    def security_policy_name(self) -> builtins.str:
        """
        安全策略名称。必须以字母、数字或中文开头，可包含以下特殊字符：点（.）、下划线（_）和中划线（-）；长度限制为1 ～ 128个字符；该参数不传入，则默认为策略ID。
        """
        return pulumi.get(self, "security_policy_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        TLS 自定义安全策略状态。Creating：创建中。Configuring：配置中。Active：正常。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetNlbSecurityPolicyTagResult']:
        """
        标签列表。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="tlsVersions")
    def tls_versions(self) -> Sequence[builtins.str]:
        """
        更新TLS自定义安全策略的TLS 协议版本。取值：TLSv1.0，TLSv1.1，TLSv1.2，TLSv1.3。当传入此参数时，需要传入待支持的全部TLS版本，不支持通过此接口仅新增/删除TLS协议版本。仅传入TlsVersions.N，未传入Ciphers.N，则依据请求中传入的TLS协议版本和当前监听器支持的加密套件做校验。传入TlsVersions.N和Ciphers.N，则依据请求中传入的TLS协议版本和加密套件做校验。
        """
        return pulumi.get(self, "tls_versions")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")


class AwaitableGetNlbSecurityPolicyResult(GetNlbSecurityPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNlbSecurityPolicyResult(
            account_id=self.account_id,
            ciphers=self.ciphers,
            created_time=self.created_time,
            id=self.id,
            project_name=self.project_name,
            related_listener_ids=self.related_listener_ids,
            security_policy_id=self.security_policy_id,
            security_policy_name=self.security_policy_name,
            status=self.status,
            tags=self.tags,
            tls_versions=self.tls_versions,
            updated_time=self.updated_time)


def get_nlb_security_policy(id: Optional[builtins.str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNlbSecurityPolicyResult:
    """
    Data Source schema for Byteplus::CLB::NLBSecurityPolicy


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:clb/getNlbSecurityPolicy:getNlbSecurityPolicy', __args__, opts=opts, typ=GetNlbSecurityPolicyResult).value

    return AwaitableGetNlbSecurityPolicyResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        ciphers=pulumi.get(__ret__, 'ciphers'),
        created_time=pulumi.get(__ret__, 'created_time'),
        id=pulumi.get(__ret__, 'id'),
        project_name=pulumi.get(__ret__, 'project_name'),
        related_listener_ids=pulumi.get(__ret__, 'related_listener_ids'),
        security_policy_id=pulumi.get(__ret__, 'security_policy_id'),
        security_policy_name=pulumi.get(__ret__, 'security_policy_name'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        tls_versions=pulumi.get(__ret__, 'tls_versions'),
        updated_time=pulumi.get(__ret__, 'updated_time'))
def get_nlb_security_policy_output(id: Optional[pulumi.Input[builtins.str]] = None,
                                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetNlbSecurityPolicyResult]:
    """
    Data Source schema for Byteplus::CLB::NLBSecurityPolicy


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:clb/getNlbSecurityPolicy:getNlbSecurityPolicy', __args__, opts=opts, typ=GetNlbSecurityPolicyResult)
    return __ret__.apply(lambda __response__: GetNlbSecurityPolicyResult(
        account_id=pulumi.get(__response__, 'account_id'),
        ciphers=pulumi.get(__response__, 'ciphers'),
        created_time=pulumi.get(__response__, 'created_time'),
        id=pulumi.get(__response__, 'id'),
        project_name=pulumi.get(__response__, 'project_name'),
        related_listener_ids=pulumi.get(__response__, 'related_listener_ids'),
        security_policy_id=pulumi.get(__response__, 'security_policy_id'),
        security_policy_name=pulumi.get(__response__, 'security_policy_name'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        tls_versions=pulumi.get(__response__, 'tls_versions'),
        updated_time=pulumi.get(__response__, 'updated_time')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['InstancePluginArgs', 'InstancePlugin']

@pulumi.input_type
class InstancePluginArgs:
    def __init__(__self__, *,
                 instance_id: pulumi.Input[builtins.str],
                 plugin_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a InstancePlugin resource.
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] plugin_name: 插件名称。
        """
        pulumi.set(__self__, "instance_id", instance_id)
        if plugin_name is not None:
            pulumi.set(__self__, "plugin_name", plugin_name)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[builtins.str]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="pluginName")
    def plugin_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        插件名称。
        """
        return pulumi.get(self, "plugin_name")

    @plugin_name.setter
    def plugin_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "plugin_name", value)


@pulumi.input_type
class _InstancePluginState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 disable_prompt: Optional[pulumi.Input[builtins.str]] = None,
                 enable_prompt: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 need_reboot_on_change: Optional[pulumi.Input[builtins.bool]] = None,
                 plugin_name: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering InstancePlugin resources.
        :param pulumi.Input[builtins.str] description: 插件描述。
        :param pulumi.Input[builtins.str] disable_prompt: 关闭此插件的注意事项说明。
        :param pulumi.Input[builtins.str] enable_prompt: 开启此插件的注意事项说明。
        :param pulumi.Input[builtins.bool] enabled: 是否已开启插件。true：插件已开启。false：插件已关闭。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.bool] need_reboot_on_change: 开启或关闭插件是否会引发 RabbitMQ 实例重启。true：会重启实例。false：不会重启实例。
        :param pulumi.Input[builtins.str] plugin_name: 插件名称。
        :param pulumi.Input[builtins.int] port: 插件监听的端口。
        :param pulumi.Input[builtins.str] version: 插件版本。
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if disable_prompt is not None:
            pulumi.set(__self__, "disable_prompt", disable_prompt)
        if enable_prompt is not None:
            pulumi.set(__self__, "enable_prompt", enable_prompt)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if need_reboot_on_change is not None:
            pulumi.set(__self__, "need_reboot_on_change", need_reboot_on_change)
        if plugin_name is not None:
            pulumi.set(__self__, "plugin_name", plugin_name)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        插件描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="disablePrompt")
    def disable_prompt(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        关闭此插件的注意事项说明。
        """
        return pulumi.get(self, "disable_prompt")

    @disable_prompt.setter
    def disable_prompt(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "disable_prompt", value)

    @property
    @pulumi.getter(name="enablePrompt")
    def enable_prompt(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        开启此插件的注意事项说明。
        """
        return pulumi.get(self, "enable_prompt")

    @enable_prompt.setter
    def enable_prompt(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "enable_prompt", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否已开启插件。true：插件已开启。false：插件已关闭。
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="needRebootOnChange")
    def need_reboot_on_change(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        开启或关闭插件是否会引发 RabbitMQ 实例重启。true：会重启实例。false：不会重启实例。
        """
        return pulumi.get(self, "need_reboot_on_change")

    @need_reboot_on_change.setter
    def need_reboot_on_change(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "need_reboot_on_change", value)

    @property
    @pulumi.getter(name="pluginName")
    def plugin_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        插件名称。
        """
        return pulumi.get(self, "plugin_name")

    @plugin_name.setter
    def plugin_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "plugin_name", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        插件监听的端口。
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        插件版本。
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version", value)


@pulumi.type_token("bytepluscc:rabbitmq/instancePlugin:InstancePlugin")
class InstancePlugin(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 plugin_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        在消息队列 RabbitMQ版控制台中创建实例之后，实例插件默认为关闭状态，您可以手动为实例开启/关闭插件。开启/关闭部分插件会导致集群滚动重启，建议避开业务运行时段执行该操作。集群滚动重启时会造成未持久化的消息丢失，也会出现短暂的连接不稳定现象，例如连接断开，断开后会根据客户端配置决定是否自动重连。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        instanceplugin_demo = bytepluscc.rabbitmq.InstancePlugin("instancepluginDemo",
            instance_id="rbtmq-db26b7****",
            plugin_name="ccapi-test")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:rabbitmq/instancePlugin:InstancePlugin example "instance_id|plugin_name"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] plugin_name: 插件名称。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstancePluginArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        在消息队列 RabbitMQ版控制台中创建实例之后，实例插件默认为关闭状态，您可以手动为实例开启/关闭插件。开启/关闭部分插件会导致集群滚动重启，建议避开业务运行时段执行该操作。集群滚动重启时会造成未持久化的消息丢失，也会出现短暂的连接不稳定现象，例如连接断开，断开后会根据客户端配置决定是否自动重连。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        instanceplugin_demo = bytepluscc.rabbitmq.InstancePlugin("instancepluginDemo",
            instance_id="rbtmq-db26b7****",
            plugin_name="ccapi-test")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:rabbitmq/instancePlugin:InstancePlugin example "instance_id|plugin_name"
        ```

        :param str resource_name: The name of the resource.
        :param InstancePluginArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstancePluginArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 plugin_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstancePluginArgs.__new__(InstancePluginArgs)

            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["plugin_name"] = plugin_name
            __props__.__dict__["description"] = None
            __props__.__dict__["disable_prompt"] = None
            __props__.__dict__["enable_prompt"] = None
            __props__.__dict__["enabled"] = None
            __props__.__dict__["need_reboot_on_change"] = None
            __props__.__dict__["port"] = None
            __props__.__dict__["version"] = None
        super(InstancePlugin, __self__).__init__(
            'bytepluscc:rabbitmq/instancePlugin:InstancePlugin',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            disable_prompt: Optional[pulumi.Input[builtins.str]] = None,
            enable_prompt: Optional[pulumi.Input[builtins.str]] = None,
            enabled: Optional[pulumi.Input[builtins.bool]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            need_reboot_on_change: Optional[pulumi.Input[builtins.bool]] = None,
            plugin_name: Optional[pulumi.Input[builtins.str]] = None,
            port: Optional[pulumi.Input[builtins.int]] = None,
            version: Optional[pulumi.Input[builtins.str]] = None) -> 'InstancePlugin':
        """
        Get an existing InstancePlugin resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: 插件描述。
        :param pulumi.Input[builtins.str] disable_prompt: 关闭此插件的注意事项说明。
        :param pulumi.Input[builtins.str] enable_prompt: 开启此插件的注意事项说明。
        :param pulumi.Input[builtins.bool] enabled: 是否已开启插件。true：插件已开启。false：插件已关闭。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.bool] need_reboot_on_change: 开启或关闭插件是否会引发 RabbitMQ 实例重启。true：会重启实例。false：不会重启实例。
        :param pulumi.Input[builtins.str] plugin_name: 插件名称。
        :param pulumi.Input[builtins.int] port: 插件监听的端口。
        :param pulumi.Input[builtins.str] version: 插件版本。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstancePluginState.__new__(_InstancePluginState)

        __props__.__dict__["description"] = description
        __props__.__dict__["disable_prompt"] = disable_prompt
        __props__.__dict__["enable_prompt"] = enable_prompt
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["need_reboot_on_change"] = need_reboot_on_change
        __props__.__dict__["plugin_name"] = plugin_name
        __props__.__dict__["port"] = port
        __props__.__dict__["version"] = version
        return InstancePlugin(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        插件描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="disablePrompt")
    def disable_prompt(self) -> pulumi.Output[builtins.str]:
        """
        关闭此插件的注意事项说明。
        """
        return pulumi.get(self, "disable_prompt")

    @property
    @pulumi.getter(name="enablePrompt")
    def enable_prompt(self) -> pulumi.Output[builtins.str]:
        """
        开启此插件的注意事项说明。
        """
        return pulumi.get(self, "enable_prompt")

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否已开启插件。true：插件已开启。false：插件已关闭。
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="needRebootOnChange")
    def need_reboot_on_change(self) -> pulumi.Output[builtins.bool]:
        """
        开启或关闭插件是否会引发 RabbitMQ 实例重启。true：会重启实例。false：不会重启实例。
        """
        return pulumi.get(self, "need_reboot_on_change")

    @property
    @pulumi.getter(name="pluginName")
    def plugin_name(self) -> pulumi.Output[builtins.str]:
        """
        插件名称。
        """
        return pulumi.get(self, "plugin_name")

    @property
    @pulumi.getter
    def port(self) -> pulumi.Output[builtins.int]:
        """
        插件监听的端口。
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter
    def version(self) -> pulumi.Output[builtins.str]:
        """
        插件版本。
        """
        return pulumi.get(self, "version")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'AllowListAssociatedInstance',
    'AllowListSecurityGroupBindInfo',
    'GetAllowListAssociatedInstanceResult',
    'GetAllowListSecurityGroupBindInfoResult',
]

@pulumi.output_type
class AllowListAssociatedInstance(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "instanceId":
            suggest = "instance_id"
        elif key == "instanceName":
            suggest = "instance_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AllowListAssociatedInstance. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AllowListAssociatedInstance.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AllowListAssociatedInstance.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 instance_id: Optional[builtins.str] = None,
                 instance_name: Optional[builtins.str] = None,
                 vpc: Optional[builtins.str] = None):
        """
        :param builtins.str instance_id: 实例 ID。
        :param builtins.str instance_name: 实例名称。
        :param builtins.str vpc: 实例所属的 VPC ID。
        """
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if instance_name is not None:
            pulumi.set(__self__, "instance_name", instance_name)
        if vpc is not None:
            pulumi.set(__self__, "vpc", vpc)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[builtins.str]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> Optional[builtins.str]:
        """
        实例名称。
        """
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter
    def vpc(self) -> Optional[builtins.str]:
        """
        实例所属的 VPC ID。
        """
        return pulumi.get(self, "vpc")


@pulumi.output_type
class AllowListSecurityGroupBindInfo(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "bindMode":
            suggest = "bind_mode"
        elif key == "ipLists":
            suggest = "ip_lists"
        elif key == "securityGroupId":
            suggest = "security_group_id"
        elif key == "securityGroupName":
            suggest = "security_group_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AllowListSecurityGroupBindInfo. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AllowListSecurityGroupBindInfo.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AllowListSecurityGroupBindInfo.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 bind_mode: Optional[builtins.str] = None,
                 ip_lists: Optional[Sequence[builtins.str]] = None,
                 security_group_id: Optional[builtins.str] = None,
                 security_group_name: Optional[builtins.str] = None):
        """
        :param builtins.str bind_mode: 关联安全组的模式。取值：IngressDirectionIp：入方向 IP。AssociateEcsIp：关联 ECSIP。
        :param Sequence[builtins.str] ip_lists: 安全组中的 IP 列表。
        :param builtins.str security_group_id: 安全组 ID。
        :param builtins.str security_group_name: 安全组名称。
        """
        if bind_mode is not None:
            pulumi.set(__self__, "bind_mode", bind_mode)
        if ip_lists is not None:
            pulumi.set(__self__, "ip_lists", ip_lists)
        if security_group_id is not None:
            pulumi.set(__self__, "security_group_id", security_group_id)
        if security_group_name is not None:
            pulumi.set(__self__, "security_group_name", security_group_name)

    @property
    @pulumi.getter(name="bindMode")
    def bind_mode(self) -> Optional[builtins.str]:
        """
        关联安全组的模式。取值：IngressDirectionIp：入方向 IP。AssociateEcsIp：关联 ECSIP。
        """
        return pulumi.get(self, "bind_mode")

    @property
    @pulumi.getter(name="ipLists")
    def ip_lists(self) -> Optional[Sequence[builtins.str]]:
        """
        安全组中的 IP 列表。
        """
        return pulumi.get(self, "ip_lists")

    @property
    @pulumi.getter(name="securityGroupId")
    def security_group_id(self) -> Optional[builtins.str]:
        """
        安全组 ID。
        """
        return pulumi.get(self, "security_group_id")

    @property
    @pulumi.getter(name="securityGroupName")
    def security_group_name(self) -> Optional[builtins.str]:
        """
        安全组名称。
        """
        return pulumi.get(self, "security_group_name")


@pulumi.output_type
class GetAllowListAssociatedInstanceResult(dict):
    def __init__(__self__, *,
                 instance_id: builtins.str,
                 instance_name: builtins.str,
                 vpc: builtins.str):
        """
        :param builtins.str instance_id: 实例 ID。
        :param builtins.str instance_name: 实例名称。
        :param builtins.str vpc: 实例所属的 VPC ID。
        """
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "instance_name", instance_name)
        pulumi.set(__self__, "vpc", vpc)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> builtins.str:
        """
        实例名称。
        """
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter
    def vpc(self) -> builtins.str:
        """
        实例所属的 VPC ID。
        """
        return pulumi.get(self, "vpc")


@pulumi.output_type
class GetAllowListSecurityGroupBindInfoResult(dict):
    def __init__(__self__, *,
                 bind_mode: builtins.str,
                 ip_lists: Sequence[builtins.str],
                 security_group_id: builtins.str,
                 security_group_name: builtins.str):
        """
        :param builtins.str bind_mode: 关联安全组的模式。取值：IngressDirectionIp：入方向 IP。AssociateEcsIp：关联 ECSIP。
        :param Sequence[builtins.str] ip_lists: 安全组中的 IP 列表。
        :param builtins.str security_group_id: 安全组 ID。
        :param builtins.str security_group_name: 安全组名称。
        """
        pulumi.set(__self__, "bind_mode", bind_mode)
        pulumi.set(__self__, "ip_lists", ip_lists)
        pulumi.set(__self__, "security_group_id", security_group_id)
        pulumi.set(__self__, "security_group_name", security_group_name)

    @property
    @pulumi.getter(name="bindMode")
    def bind_mode(self) -> builtins.str:
        """
        关联安全组的模式。取值：IngressDirectionIp：入方向 IP。AssociateEcsIp：关联 ECSIP。
        """
        return pulumi.get(self, "bind_mode")

    @property
    @pulumi.getter(name="ipLists")
    def ip_lists(self) -> Sequence[builtins.str]:
        """
        安全组中的 IP 列表。
        """
        return pulumi.get(self, "ip_lists")

    @property
    @pulumi.getter(name="securityGroupId")
    def security_group_id(self) -> builtins.str:
        """
        安全组 ID。
        """
        return pulumi.get(self, "security_group_id")

    @property
    @pulumi.getter(name="securityGroupName")
    def security_group_name(self) -> builtins.str:
        """
        安全组名称。
        """
        return pulumi.get(self, "security_group_name")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['LaunchTemplateVersionArgs', 'LaunchTemplateVersion']

@pulumi.input_type
class LaunchTemplateVersionArgs:
    def __init__(__self__, *,
                 deployment_set_group_number: Optional[pulumi.Input[builtins.int]] = None,
                 deployment_set_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 eip: Optional[pulumi.Input['LaunchTemplateVersionEipArgs']] = None,
                 host_name: Optional[pulumi.Input[builtins.str]] = None,
                 hpc_cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 image_id: Optional[pulumi.Input[builtins.str]] = None,
                 image_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_charge_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type_id: Optional[pulumi.Input[builtins.str]] = None,
                 keep_image_credential: Optional[pulumi.Input[builtins.bool]] = None,
                 key_pair_name: Optional[pulumi.Input[builtins.str]] = None,
                 launch_template_id: Optional[pulumi.Input[builtins.str]] = None,
                 network_interfaces: Optional[pulumi.Input[Sequence[pulumi.Input['LaunchTemplateVersionNetworkInterfaceArgs']]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 scheduled_instance: Optional[pulumi.Input['LaunchTemplateVersionScheduledInstanceArgs']] = None,
                 security_enhancement_strategy: Optional[pulumi.Input[builtins.str]] = None,
                 spot_price_limit: Optional[pulumi.Input[builtins.float]] = None,
                 spot_strategy: Optional[pulumi.Input[builtins.str]] = None,
                 suffix_index: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['LaunchTemplateVersionTagArgs']]]] = None,
                 unique_suffix: Optional[pulumi.Input[builtins.bool]] = None,
                 user_data: Optional[pulumi.Input[builtins.str]] = None,
                 version_description: Optional[pulumi.Input[builtins.str]] = None,
                 volumes: Optional[pulumi.Input[Sequence[pulumi.Input['LaunchTemplateVersionVolumeArgs']]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a LaunchTemplateVersion resource.
        :param pulumi.Input[builtins.int] deployment_set_group_number: 当ECS实例要加入或调整的部署集策略为部署集组高可用策略（AvailabilityGroup）时，可以通过该参数指定实例在部署集中的分组号。
        :param pulumi.Input[builtins.str] deployment_set_id: 实例需要加入的部署集ID。
        :param pulumi.Input[builtins.str] description: 实例的描述。
        :param pulumi.Input['LaunchTemplateVersionEipArgs'] eip: 实例绑定的公网IP信息。
        :param pulumi.Input[builtins.str] host_name: 实例的主机名。Linux系统的主机名长度限制为2～59个字符。Windows系统的主机名长度限制为2～10个字符。
        :param pulumi.Input[builtins.str] hpc_cluster_id: 当创建高性能计算GPU型实例时，请指定高性能计算集群ID。
        :param pulumi.Input[builtins.str] image_id: 镜像ID。
        :param pulumi.Input[builtins.str] image_name: 镜像名称。
        :param pulumi.Input[builtins.str] instance_charge_type: 实例和云盘的计费类型，取值：PostPaid：按量计费。PrePaid：包年包月。Esi：弹性预约实例。Segmented：时段型弹性预约实例。
        :param pulumi.Input[builtins.str] instance_name: 实例的名称。
        :param pulumi.Input[builtins.str] instance_type_id: 实例的规格。
        :param pulumi.Input[builtins.bool] keep_image_credential: 是否保留镜像设置，取值：true：保留镜像设置，保留后将使用镜像预设的密码或密钥对登录实例。false（默认）：不保留镜像设置。
        :param pulumi.Input[builtins.str] key_pair_name: 实例绑定的密钥对。
        :param pulumi.Input[builtins.str] launch_template_id: 实例启动模板 ID。
        :param pulumi.Input[builtins.str] project_name: 实例所属项目。
        :param pulumi.Input['LaunchTemplateVersionScheduledInstanceArgs'] scheduled_instance: 弹性预约单信息。
        :param pulumi.Input[builtins.str] security_enhancement_strategy: 是否开启安全加固。Active:开启安全加固，仅对公共镜像生效。InActive:关闭安全加固，对所有镜像生效。
        :param pulumi.Input[builtins.float] spot_price_limit: 抢占式实例的每小时最高价格。
        :param pulumi.Input[builtins.str] spot_strategy: 按量计费的抢占式策略。取值：NoSpot：表示创建正常按量计费实例。SpotAsPriceGo：系统自动出价，跟随当前市场实际价格的抢占式实例。SpotWithPriceLimit：设置出价上限的抢占式实例。
        :param pulumi.Input[builtins.int] suffix_index: 有序后缀的起始序号。
        :param pulumi.Input[builtins.bool] unique_suffix: 表示当创建多台实例时，是否为Hostname和InstanceName自动添加有序后缀。
        :param pulumi.Input[builtins.str] user_data: 实例的自定义数据。
        :param pulumi.Input[builtins.str] version_description: 模版版本描述。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络ID。
        :param pulumi.Input[builtins.str] zone_id: 实例所属可用区ID。
        """
        if deployment_set_group_number is not None:
            pulumi.set(__self__, "deployment_set_group_number", deployment_set_group_number)
        if deployment_set_id is not None:
            pulumi.set(__self__, "deployment_set_id", deployment_set_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if eip is not None:
            pulumi.set(__self__, "eip", eip)
        if host_name is not None:
            pulumi.set(__self__, "host_name", host_name)
        if hpc_cluster_id is not None:
            pulumi.set(__self__, "hpc_cluster_id", hpc_cluster_id)
        if image_id is not None:
            pulumi.set(__self__, "image_id", image_id)
        if image_name is not None:
            pulumi.set(__self__, "image_name", image_name)
        if instance_charge_type is not None:
            pulumi.set(__self__, "instance_charge_type", instance_charge_type)
        if instance_name is not None:
            pulumi.set(__self__, "instance_name", instance_name)
        if instance_type_id is not None:
            pulumi.set(__self__, "instance_type_id", instance_type_id)
        if keep_image_credential is not None:
            pulumi.set(__self__, "keep_image_credential", keep_image_credential)
        if key_pair_name is not None:
            pulumi.set(__self__, "key_pair_name", key_pair_name)
        if launch_template_id is not None:
            pulumi.set(__self__, "launch_template_id", launch_template_id)
        if network_interfaces is not None:
            pulumi.set(__self__, "network_interfaces", network_interfaces)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if scheduled_instance is not None:
            pulumi.set(__self__, "scheduled_instance", scheduled_instance)
        if security_enhancement_strategy is not None:
            pulumi.set(__self__, "security_enhancement_strategy", security_enhancement_strategy)
        if spot_price_limit is not None:
            pulumi.set(__self__, "spot_price_limit", spot_price_limit)
        if spot_strategy is not None:
            pulumi.set(__self__, "spot_strategy", spot_strategy)
        if suffix_index is not None:
            pulumi.set(__self__, "suffix_index", suffix_index)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if unique_suffix is not None:
            pulumi.set(__self__, "unique_suffix", unique_suffix)
        if user_data is not None:
            pulumi.set(__self__, "user_data", user_data)
        if version_description is not None:
            pulumi.set(__self__, "version_description", version_description)
        if volumes is not None:
            pulumi.set(__self__, "volumes", volumes)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="deploymentSetGroupNumber")
    def deployment_set_group_number(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        当ECS实例要加入或调整的部署集策略为部署集组高可用策略（AvailabilityGroup）时，可以通过该参数指定实例在部署集中的分组号。
        """
        return pulumi.get(self, "deployment_set_group_number")

    @deployment_set_group_number.setter
    def deployment_set_group_number(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "deployment_set_group_number", value)

    @property
    @pulumi.getter(name="deploymentSetId")
    def deployment_set_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例需要加入的部署集ID。
        """
        return pulumi.get(self, "deployment_set_id")

    @deployment_set_id.setter
    def deployment_set_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "deployment_set_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def eip(self) -> Optional[pulumi.Input['LaunchTemplateVersionEipArgs']]:
        """
        实例绑定的公网IP信息。
        """
        return pulumi.get(self, "eip")

    @eip.setter
    def eip(self, value: Optional[pulumi.Input['LaunchTemplateVersionEipArgs']]):
        pulumi.set(self, "eip", value)

    @property
    @pulumi.getter(name="hostName")
    def host_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的主机名。Linux系统的主机名长度限制为2～59个字符。Windows系统的主机名长度限制为2～10个字符。
        """
        return pulumi.get(self, "host_name")

    @host_name.setter
    def host_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "host_name", value)

    @property
    @pulumi.getter(name="hpcClusterId")
    def hpc_cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        当创建高性能计算GPU型实例时，请指定高性能计算集群ID。
        """
        return pulumi.get(self, "hpc_cluster_id")

    @hpc_cluster_id.setter
    def hpc_cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "hpc_cluster_id", value)

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像ID。
        """
        return pulumi.get(self, "image_id")

    @image_id.setter
    def image_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_id", value)

    @property
    @pulumi.getter(name="imageName")
    def image_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像名称。
        """
        return pulumi.get(self, "image_name")

    @image_name.setter
    def image_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_name", value)

    @property
    @pulumi.getter(name="instanceChargeType")
    def instance_charge_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例和云盘的计费类型，取值：PostPaid：按量计费。PrePaid：包年包月。Esi：弹性预约实例。Segmented：时段型弹性预约实例。
        """
        return pulumi.get(self, "instance_charge_type")

    @instance_charge_type.setter
    def instance_charge_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_charge_type", value)

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的名称。
        """
        return pulumi.get(self, "instance_name")

    @instance_name.setter
    def instance_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_name", value)

    @property
    @pulumi.getter(name="instanceTypeId")
    def instance_type_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的规格。
        """
        return pulumi.get(self, "instance_type_id")

    @instance_type_id.setter
    def instance_type_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_type_id", value)

    @property
    @pulumi.getter(name="keepImageCredential")
    def keep_image_credential(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否保留镜像设置，取值：true：保留镜像设置，保留后将使用镜像预设的密码或密钥对登录实例。false（默认）：不保留镜像设置。
        """
        return pulumi.get(self, "keep_image_credential")

    @keep_image_credential.setter
    def keep_image_credential(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "keep_image_credential", value)

    @property
    @pulumi.getter(name="keyPairName")
    def key_pair_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例绑定的密钥对。
        """
        return pulumi.get(self, "key_pair_name")

    @key_pair_name.setter
    def key_pair_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key_pair_name", value)

    @property
    @pulumi.getter(name="launchTemplateId")
    def launch_template_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例启动模板 ID。
        """
        return pulumi.get(self, "launch_template_id")

    @launch_template_id.setter
    def launch_template_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "launch_template_id", value)

    @property
    @pulumi.getter(name="networkInterfaces")
    def network_interfaces(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LaunchTemplateVersionNetworkInterfaceArgs']]]]:
        return pulumi.get(self, "network_interfaces")

    @network_interfaces.setter
    def network_interfaces(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LaunchTemplateVersionNetworkInterfaceArgs']]]]):
        pulumi.set(self, "network_interfaces", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所属项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="scheduledInstance")
    def scheduled_instance(self) -> Optional[pulumi.Input['LaunchTemplateVersionScheduledInstanceArgs']]:
        """
        弹性预约单信息。
        """
        return pulumi.get(self, "scheduled_instance")

    @scheduled_instance.setter
    def scheduled_instance(self, value: Optional[pulumi.Input['LaunchTemplateVersionScheduledInstanceArgs']]):
        pulumi.set(self, "scheduled_instance", value)

    @property
    @pulumi.getter(name="securityEnhancementStrategy")
    def security_enhancement_strategy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        是否开启安全加固。Active:开启安全加固，仅对公共镜像生效。InActive:关闭安全加固，对所有镜像生效。
        """
        return pulumi.get(self, "security_enhancement_strategy")

    @security_enhancement_strategy.setter
    def security_enhancement_strategy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "security_enhancement_strategy", value)

    @property
    @pulumi.getter(name="spotPriceLimit")
    def spot_price_limit(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        抢占式实例的每小时最高价格。
        """
        return pulumi.get(self, "spot_price_limit")

    @spot_price_limit.setter
    def spot_price_limit(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "spot_price_limit", value)

    @property
    @pulumi.getter(name="spotStrategy")
    def spot_strategy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        按量计费的抢占式策略。取值：NoSpot：表示创建正常按量计费实例。SpotAsPriceGo：系统自动出价，跟随当前市场实际价格的抢占式实例。SpotWithPriceLimit：设置出价上限的抢占式实例。
        """
        return pulumi.get(self, "spot_strategy")

    @spot_strategy.setter
    def spot_strategy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "spot_strategy", value)

    @property
    @pulumi.getter(name="suffixIndex")
    def suffix_index(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        有序后缀的起始序号。
        """
        return pulumi.get(self, "suffix_index")

    @suffix_index.setter
    def suffix_index(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "suffix_index", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LaunchTemplateVersionTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LaunchTemplateVersionTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="uniqueSuffix")
    def unique_suffix(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        表示当创建多台实例时，是否为Hostname和InstanceName自动添加有序后缀。
        """
        return pulumi.get(self, "unique_suffix")

    @unique_suffix.setter
    def unique_suffix(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "unique_suffix", value)

    @property
    @pulumi.getter(name="userData")
    def user_data(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的自定义数据。
        """
        return pulumi.get(self, "user_data")

    @user_data.setter
    def user_data(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_data", value)

    @property
    @pulumi.getter(name="versionDescription")
    def version_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        模版版本描述。
        """
        return pulumi.get(self, "version_description")

    @version_description.setter
    def version_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version_description", value)

    @property
    @pulumi.getter
    def volumes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LaunchTemplateVersionVolumeArgs']]]]:
        return pulumi.get(self, "volumes")

    @volumes.setter
    def volumes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LaunchTemplateVersionVolumeArgs']]]]):
        pulumi.set(self, "volumes", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私有网络ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所属可用区ID。
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)


@pulumi.input_type
class _LaunchTemplateVersionState:
    def __init__(__self__, *,
                 deployment_set_group_number: Optional[pulumi.Input[builtins.int]] = None,
                 deployment_set_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 eip: Optional[pulumi.Input['LaunchTemplateVersionEipArgs']] = None,
                 host_name: Optional[pulumi.Input[builtins.str]] = None,
                 hpc_cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 image_id: Optional[pulumi.Input[builtins.str]] = None,
                 image_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_charge_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type_id: Optional[pulumi.Input[builtins.str]] = None,
                 keep_image_credential: Optional[pulumi.Input[builtins.bool]] = None,
                 key_pair_name: Optional[pulumi.Input[builtins.str]] = None,
                 launch_template_id: Optional[pulumi.Input[builtins.str]] = None,
                 network_interfaces: Optional[pulumi.Input[Sequence[pulumi.Input['LaunchTemplateVersionNetworkInterfaceArgs']]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 scheduled_instance: Optional[pulumi.Input['LaunchTemplateVersionScheduledInstanceArgs']] = None,
                 security_enhancement_strategy: Optional[pulumi.Input[builtins.str]] = None,
                 spot_price_limit: Optional[pulumi.Input[builtins.float]] = None,
                 spot_strategy: Optional[pulumi.Input[builtins.str]] = None,
                 suffix_index: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['LaunchTemplateVersionTagArgs']]]] = None,
                 unique_suffix: Optional[pulumi.Input[builtins.bool]] = None,
                 user_data: Optional[pulumi.Input[builtins.str]] = None,
                 version_description: Optional[pulumi.Input[builtins.str]] = None,
                 version_number: Optional[pulumi.Input[builtins.str]] = None,
                 volumes: Optional[pulumi.Input[Sequence[pulumi.Input['LaunchTemplateVersionVolumeArgs']]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering LaunchTemplateVersion resources.
        :param pulumi.Input[builtins.int] deployment_set_group_number: 当ECS实例要加入或调整的部署集策略为部署集组高可用策略（AvailabilityGroup）时，可以通过该参数指定实例在部署集中的分组号。
        :param pulumi.Input[builtins.str] deployment_set_id: 实例需要加入的部署集ID。
        :param pulumi.Input[builtins.str] description: 实例的描述。
        :param pulumi.Input['LaunchTemplateVersionEipArgs'] eip: 实例绑定的公网IP信息。
        :param pulumi.Input[builtins.str] host_name: 实例的主机名。Linux系统的主机名长度限制为2～59个字符。Windows系统的主机名长度限制为2～10个字符。
        :param pulumi.Input[builtins.str] hpc_cluster_id: 当创建高性能计算GPU型实例时，请指定高性能计算集群ID。
        :param pulumi.Input[builtins.str] image_id: 镜像ID。
        :param pulumi.Input[builtins.str] image_name: 镜像名称。
        :param pulumi.Input[builtins.str] instance_charge_type: 实例和云盘的计费类型，取值：PostPaid：按量计费。PrePaid：包年包月。Esi：弹性预约实例。Segmented：时段型弹性预约实例。
        :param pulumi.Input[builtins.str] instance_name: 实例的名称。
        :param pulumi.Input[builtins.str] instance_type_id: 实例的规格。
        :param pulumi.Input[builtins.bool] keep_image_credential: 是否保留镜像设置，取值：true：保留镜像设置，保留后将使用镜像预设的密码或密钥对登录实例。false（默认）：不保留镜像设置。
        :param pulumi.Input[builtins.str] key_pair_name: 实例绑定的密钥对。
        :param pulumi.Input[builtins.str] launch_template_id: 实例启动模板 ID。
        :param pulumi.Input[builtins.str] project_name: 实例所属项目。
        :param pulumi.Input['LaunchTemplateVersionScheduledInstanceArgs'] scheduled_instance: 弹性预约单信息。
        :param pulumi.Input[builtins.str] security_enhancement_strategy: 是否开启安全加固。Active:开启安全加固，仅对公共镜像生效。InActive:关闭安全加固，对所有镜像生效。
        :param pulumi.Input[builtins.float] spot_price_limit: 抢占式实例的每小时最高价格。
        :param pulumi.Input[builtins.str] spot_strategy: 按量计费的抢占式策略。取值：NoSpot：表示创建正常按量计费实例。SpotAsPriceGo：系统自动出价，跟随当前市场实际价格的抢占式实例。SpotWithPriceLimit：设置出价上限的抢占式实例。
        :param pulumi.Input[builtins.int] suffix_index: 有序后缀的起始序号。
        :param pulumi.Input[builtins.bool] unique_suffix: 表示当创建多台实例时，是否为Hostname和InstanceName自动添加有序后缀。
        :param pulumi.Input[builtins.str] user_data: 实例的自定义数据。
        :param pulumi.Input[builtins.str] version_description: 模版版本描述。
        :param pulumi.Input[builtins.str] version_number: 模板版本号。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络ID。
        :param pulumi.Input[builtins.str] zone_id: 实例所属可用区ID。
        """
        if deployment_set_group_number is not None:
            pulumi.set(__self__, "deployment_set_group_number", deployment_set_group_number)
        if deployment_set_id is not None:
            pulumi.set(__self__, "deployment_set_id", deployment_set_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if eip is not None:
            pulumi.set(__self__, "eip", eip)
        if host_name is not None:
            pulumi.set(__self__, "host_name", host_name)
        if hpc_cluster_id is not None:
            pulumi.set(__self__, "hpc_cluster_id", hpc_cluster_id)
        if image_id is not None:
            pulumi.set(__self__, "image_id", image_id)
        if image_name is not None:
            pulumi.set(__self__, "image_name", image_name)
        if instance_charge_type is not None:
            pulumi.set(__self__, "instance_charge_type", instance_charge_type)
        if instance_name is not None:
            pulumi.set(__self__, "instance_name", instance_name)
        if instance_type_id is not None:
            pulumi.set(__self__, "instance_type_id", instance_type_id)
        if keep_image_credential is not None:
            pulumi.set(__self__, "keep_image_credential", keep_image_credential)
        if key_pair_name is not None:
            pulumi.set(__self__, "key_pair_name", key_pair_name)
        if launch_template_id is not None:
            pulumi.set(__self__, "launch_template_id", launch_template_id)
        if network_interfaces is not None:
            pulumi.set(__self__, "network_interfaces", network_interfaces)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if scheduled_instance is not None:
            pulumi.set(__self__, "scheduled_instance", scheduled_instance)
        if security_enhancement_strategy is not None:
            pulumi.set(__self__, "security_enhancement_strategy", security_enhancement_strategy)
        if spot_price_limit is not None:
            pulumi.set(__self__, "spot_price_limit", spot_price_limit)
        if spot_strategy is not None:
            pulumi.set(__self__, "spot_strategy", spot_strategy)
        if suffix_index is not None:
            pulumi.set(__self__, "suffix_index", suffix_index)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if unique_suffix is not None:
            pulumi.set(__self__, "unique_suffix", unique_suffix)
        if user_data is not None:
            pulumi.set(__self__, "user_data", user_data)
        if version_description is not None:
            pulumi.set(__self__, "version_description", version_description)
        if version_number is not None:
            pulumi.set(__self__, "version_number", version_number)
        if volumes is not None:
            pulumi.set(__self__, "volumes", volumes)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="deploymentSetGroupNumber")
    def deployment_set_group_number(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        当ECS实例要加入或调整的部署集策略为部署集组高可用策略（AvailabilityGroup）时，可以通过该参数指定实例在部署集中的分组号。
        """
        return pulumi.get(self, "deployment_set_group_number")

    @deployment_set_group_number.setter
    def deployment_set_group_number(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "deployment_set_group_number", value)

    @property
    @pulumi.getter(name="deploymentSetId")
    def deployment_set_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例需要加入的部署集ID。
        """
        return pulumi.get(self, "deployment_set_id")

    @deployment_set_id.setter
    def deployment_set_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "deployment_set_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def eip(self) -> Optional[pulumi.Input['LaunchTemplateVersionEipArgs']]:
        """
        实例绑定的公网IP信息。
        """
        return pulumi.get(self, "eip")

    @eip.setter
    def eip(self, value: Optional[pulumi.Input['LaunchTemplateVersionEipArgs']]):
        pulumi.set(self, "eip", value)

    @property
    @pulumi.getter(name="hostName")
    def host_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的主机名。Linux系统的主机名长度限制为2～59个字符。Windows系统的主机名长度限制为2～10个字符。
        """
        return pulumi.get(self, "host_name")

    @host_name.setter
    def host_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "host_name", value)

    @property
    @pulumi.getter(name="hpcClusterId")
    def hpc_cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        当创建高性能计算GPU型实例时，请指定高性能计算集群ID。
        """
        return pulumi.get(self, "hpc_cluster_id")

    @hpc_cluster_id.setter
    def hpc_cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "hpc_cluster_id", value)

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像ID。
        """
        return pulumi.get(self, "image_id")

    @image_id.setter
    def image_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_id", value)

    @property
    @pulumi.getter(name="imageName")
    def image_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像名称。
        """
        return pulumi.get(self, "image_name")

    @image_name.setter
    def image_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_name", value)

    @property
    @pulumi.getter(name="instanceChargeType")
    def instance_charge_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例和云盘的计费类型，取值：PostPaid：按量计费。PrePaid：包年包月。Esi：弹性预约实例。Segmented：时段型弹性预约实例。
        """
        return pulumi.get(self, "instance_charge_type")

    @instance_charge_type.setter
    def instance_charge_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_charge_type", value)

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的名称。
        """
        return pulumi.get(self, "instance_name")

    @instance_name.setter
    def instance_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_name", value)

    @property
    @pulumi.getter(name="instanceTypeId")
    def instance_type_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的规格。
        """
        return pulumi.get(self, "instance_type_id")

    @instance_type_id.setter
    def instance_type_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_type_id", value)

    @property
    @pulumi.getter(name="keepImageCredential")
    def keep_image_credential(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否保留镜像设置，取值：true：保留镜像设置，保留后将使用镜像预设的密码或密钥对登录实例。false（默认）：不保留镜像设置。
        """
        return pulumi.get(self, "keep_image_credential")

    @keep_image_credential.setter
    def keep_image_credential(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "keep_image_credential", value)

    @property
    @pulumi.getter(name="keyPairName")
    def key_pair_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例绑定的密钥对。
        """
        return pulumi.get(self, "key_pair_name")

    @key_pair_name.setter
    def key_pair_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key_pair_name", value)

    @property
    @pulumi.getter(name="launchTemplateId")
    def launch_template_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例启动模板 ID。
        """
        return pulumi.get(self, "launch_template_id")

    @launch_template_id.setter
    def launch_template_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "launch_template_id", value)

    @property
    @pulumi.getter(name="networkInterfaces")
    def network_interfaces(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LaunchTemplateVersionNetworkInterfaceArgs']]]]:
        return pulumi.get(self, "network_interfaces")

    @network_interfaces.setter
    def network_interfaces(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LaunchTemplateVersionNetworkInterfaceArgs']]]]):
        pulumi.set(self, "network_interfaces", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所属项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="scheduledInstance")
    def scheduled_instance(self) -> Optional[pulumi.Input['LaunchTemplateVersionScheduledInstanceArgs']]:
        """
        弹性预约单信息。
        """
        return pulumi.get(self, "scheduled_instance")

    @scheduled_instance.setter
    def scheduled_instance(self, value: Optional[pulumi.Input['LaunchTemplateVersionScheduledInstanceArgs']]):
        pulumi.set(self, "scheduled_instance", value)

    @property
    @pulumi.getter(name="securityEnhancementStrategy")
    def security_enhancement_strategy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        是否开启安全加固。Active:开启安全加固，仅对公共镜像生效。InActive:关闭安全加固，对所有镜像生效。
        """
        return pulumi.get(self, "security_enhancement_strategy")

    @security_enhancement_strategy.setter
    def security_enhancement_strategy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "security_enhancement_strategy", value)

    @property
    @pulumi.getter(name="spotPriceLimit")
    def spot_price_limit(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        抢占式实例的每小时最高价格。
        """
        return pulumi.get(self, "spot_price_limit")

    @spot_price_limit.setter
    def spot_price_limit(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "spot_price_limit", value)

    @property
    @pulumi.getter(name="spotStrategy")
    def spot_strategy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        按量计费的抢占式策略。取值：NoSpot：表示创建正常按量计费实例。SpotAsPriceGo：系统自动出价，跟随当前市场实际价格的抢占式实例。SpotWithPriceLimit：设置出价上限的抢占式实例。
        """
        return pulumi.get(self, "spot_strategy")

    @spot_strategy.setter
    def spot_strategy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "spot_strategy", value)

    @property
    @pulumi.getter(name="suffixIndex")
    def suffix_index(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        有序后缀的起始序号。
        """
        return pulumi.get(self, "suffix_index")

    @suffix_index.setter
    def suffix_index(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "suffix_index", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LaunchTemplateVersionTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LaunchTemplateVersionTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="uniqueSuffix")
    def unique_suffix(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        表示当创建多台实例时，是否为Hostname和InstanceName自动添加有序后缀。
        """
        return pulumi.get(self, "unique_suffix")

    @unique_suffix.setter
    def unique_suffix(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "unique_suffix", value)

    @property
    @pulumi.getter(name="userData")
    def user_data(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例的自定义数据。
        """
        return pulumi.get(self, "user_data")

    @user_data.setter
    def user_data(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_data", value)

    @property
    @pulumi.getter(name="versionDescription")
    def version_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        模版版本描述。
        """
        return pulumi.get(self, "version_description")

    @version_description.setter
    def version_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version_description", value)

    @property
    @pulumi.getter(name="versionNumber")
    def version_number(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        模板版本号。
        """
        return pulumi.get(self, "version_number")

    @version_number.setter
    def version_number(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version_number", value)

    @property
    @pulumi.getter
    def volumes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LaunchTemplateVersionVolumeArgs']]]]:
        return pulumi.get(self, "volumes")

    @volumes.setter
    def volumes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LaunchTemplateVersionVolumeArgs']]]]):
        pulumi.set(self, "volumes", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私有网络ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例所属可用区ID。
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)


@pulumi.type_token("bytepluscc:ecs/launchTemplateVersion:LaunchTemplateVersion")
class LaunchTemplateVersion(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 deployment_set_group_number: Optional[pulumi.Input[builtins.int]] = None,
                 deployment_set_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 eip: Optional[pulumi.Input[Union['LaunchTemplateVersionEipArgs', 'LaunchTemplateVersionEipArgsDict']]] = None,
                 host_name: Optional[pulumi.Input[builtins.str]] = None,
                 hpc_cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 image_id: Optional[pulumi.Input[builtins.str]] = None,
                 image_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_charge_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type_id: Optional[pulumi.Input[builtins.str]] = None,
                 keep_image_credential: Optional[pulumi.Input[builtins.bool]] = None,
                 key_pair_name: Optional[pulumi.Input[builtins.str]] = None,
                 launch_template_id: Optional[pulumi.Input[builtins.str]] = None,
                 network_interfaces: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LaunchTemplateVersionNetworkInterfaceArgs', 'LaunchTemplateVersionNetworkInterfaceArgsDict']]]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 scheduled_instance: Optional[pulumi.Input[Union['LaunchTemplateVersionScheduledInstanceArgs', 'LaunchTemplateVersionScheduledInstanceArgsDict']]] = None,
                 security_enhancement_strategy: Optional[pulumi.Input[builtins.str]] = None,
                 spot_price_limit: Optional[pulumi.Input[builtins.float]] = None,
                 spot_strategy: Optional[pulumi.Input[builtins.str]] = None,
                 suffix_index: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LaunchTemplateVersionTagArgs', 'LaunchTemplateVersionTagArgsDict']]]]] = None,
                 unique_suffix: Optional[pulumi.Input[builtins.bool]] = None,
                 user_data: Optional[pulumi.Input[builtins.str]] = None,
                 version_description: Optional[pulumi.Input[builtins.str]] = None,
                 volumes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LaunchTemplateVersionVolumeArgs', 'LaunchTemplateVersionVolumeArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        实例启动模板版本是一系列实例配置信息的集合，用于快速购买实例。在模板中，您可以存储除密码外的全部配置信息，包括密钥对、计算规格、云盘、网络等，如果配置信息均有效，便可以一键成功购买实例，无需进行重复配置。

        ## Import

        ```sh
        $ pulumi import bytepluscc:ecs/launchTemplateVersion:LaunchTemplateVersion example "launch_template_id|version_number"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] deployment_set_group_number: 当ECS实例要加入或调整的部署集策略为部署集组高可用策略（AvailabilityGroup）时，可以通过该参数指定实例在部署集中的分组号。
        :param pulumi.Input[builtins.str] deployment_set_id: 实例需要加入的部署集ID。
        :param pulumi.Input[builtins.str] description: 实例的描述。
        :param pulumi.Input[Union['LaunchTemplateVersionEipArgs', 'LaunchTemplateVersionEipArgsDict']] eip: 实例绑定的公网IP信息。
        :param pulumi.Input[builtins.str] host_name: 实例的主机名。Linux系统的主机名长度限制为2～59个字符。Windows系统的主机名长度限制为2～10个字符。
        :param pulumi.Input[builtins.str] hpc_cluster_id: 当创建高性能计算GPU型实例时，请指定高性能计算集群ID。
        :param pulumi.Input[builtins.str] image_id: 镜像ID。
        :param pulumi.Input[builtins.str] image_name: 镜像名称。
        :param pulumi.Input[builtins.str] instance_charge_type: 实例和云盘的计费类型，取值：PostPaid：按量计费。PrePaid：包年包月。Esi：弹性预约实例。Segmented：时段型弹性预约实例。
        :param pulumi.Input[builtins.str] instance_name: 实例的名称。
        :param pulumi.Input[builtins.str] instance_type_id: 实例的规格。
        :param pulumi.Input[builtins.bool] keep_image_credential: 是否保留镜像设置，取值：true：保留镜像设置，保留后将使用镜像预设的密码或密钥对登录实例。false（默认）：不保留镜像设置。
        :param pulumi.Input[builtins.str] key_pair_name: 实例绑定的密钥对。
        :param pulumi.Input[builtins.str] launch_template_id: 实例启动模板 ID。
        :param pulumi.Input[builtins.str] project_name: 实例所属项目。
        :param pulumi.Input[Union['LaunchTemplateVersionScheduledInstanceArgs', 'LaunchTemplateVersionScheduledInstanceArgsDict']] scheduled_instance: 弹性预约单信息。
        :param pulumi.Input[builtins.str] security_enhancement_strategy: 是否开启安全加固。Active:开启安全加固，仅对公共镜像生效。InActive:关闭安全加固，对所有镜像生效。
        :param pulumi.Input[builtins.float] spot_price_limit: 抢占式实例的每小时最高价格。
        :param pulumi.Input[builtins.str] spot_strategy: 按量计费的抢占式策略。取值：NoSpot：表示创建正常按量计费实例。SpotAsPriceGo：系统自动出价，跟随当前市场实际价格的抢占式实例。SpotWithPriceLimit：设置出价上限的抢占式实例。
        :param pulumi.Input[builtins.int] suffix_index: 有序后缀的起始序号。
        :param pulumi.Input[builtins.bool] unique_suffix: 表示当创建多台实例时，是否为Hostname和InstanceName自动添加有序后缀。
        :param pulumi.Input[builtins.str] user_data: 实例的自定义数据。
        :param pulumi.Input[builtins.str] version_description: 模版版本描述。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络ID。
        :param pulumi.Input[builtins.str] zone_id: 实例所属可用区ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[LaunchTemplateVersionArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        实例启动模板版本是一系列实例配置信息的集合，用于快速购买实例。在模板中，您可以存储除密码外的全部配置信息，包括密钥对、计算规格、云盘、网络等，如果配置信息均有效，便可以一键成功购买实例，无需进行重复配置。

        ## Import

        ```sh
        $ pulumi import bytepluscc:ecs/launchTemplateVersion:LaunchTemplateVersion example "launch_template_id|version_number"
        ```

        :param str resource_name: The name of the resource.
        :param LaunchTemplateVersionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LaunchTemplateVersionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 deployment_set_group_number: Optional[pulumi.Input[builtins.int]] = None,
                 deployment_set_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 eip: Optional[pulumi.Input[Union['LaunchTemplateVersionEipArgs', 'LaunchTemplateVersionEipArgsDict']]] = None,
                 host_name: Optional[pulumi.Input[builtins.str]] = None,
                 hpc_cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 image_id: Optional[pulumi.Input[builtins.str]] = None,
                 image_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_charge_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_name: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type_id: Optional[pulumi.Input[builtins.str]] = None,
                 keep_image_credential: Optional[pulumi.Input[builtins.bool]] = None,
                 key_pair_name: Optional[pulumi.Input[builtins.str]] = None,
                 launch_template_id: Optional[pulumi.Input[builtins.str]] = None,
                 network_interfaces: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LaunchTemplateVersionNetworkInterfaceArgs', 'LaunchTemplateVersionNetworkInterfaceArgsDict']]]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 scheduled_instance: Optional[pulumi.Input[Union['LaunchTemplateVersionScheduledInstanceArgs', 'LaunchTemplateVersionScheduledInstanceArgsDict']]] = None,
                 security_enhancement_strategy: Optional[pulumi.Input[builtins.str]] = None,
                 spot_price_limit: Optional[pulumi.Input[builtins.float]] = None,
                 spot_strategy: Optional[pulumi.Input[builtins.str]] = None,
                 suffix_index: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LaunchTemplateVersionTagArgs', 'LaunchTemplateVersionTagArgsDict']]]]] = None,
                 unique_suffix: Optional[pulumi.Input[builtins.bool]] = None,
                 user_data: Optional[pulumi.Input[builtins.str]] = None,
                 version_description: Optional[pulumi.Input[builtins.str]] = None,
                 volumes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LaunchTemplateVersionVolumeArgs', 'LaunchTemplateVersionVolumeArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LaunchTemplateVersionArgs.__new__(LaunchTemplateVersionArgs)

            __props__.__dict__["deployment_set_group_number"] = deployment_set_group_number
            __props__.__dict__["deployment_set_id"] = deployment_set_id
            __props__.__dict__["description"] = description
            __props__.__dict__["eip"] = eip
            __props__.__dict__["host_name"] = host_name
            __props__.__dict__["hpc_cluster_id"] = hpc_cluster_id
            __props__.__dict__["image_id"] = image_id
            __props__.__dict__["image_name"] = image_name
            __props__.__dict__["instance_charge_type"] = instance_charge_type
            __props__.__dict__["instance_name"] = instance_name
            __props__.__dict__["instance_type_id"] = instance_type_id
            __props__.__dict__["keep_image_credential"] = keep_image_credential
            __props__.__dict__["key_pair_name"] = key_pair_name
            __props__.__dict__["launch_template_id"] = launch_template_id
            __props__.__dict__["network_interfaces"] = network_interfaces
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["scheduled_instance"] = scheduled_instance
            __props__.__dict__["security_enhancement_strategy"] = security_enhancement_strategy
            __props__.__dict__["spot_price_limit"] = spot_price_limit
            __props__.__dict__["spot_strategy"] = spot_strategy
            __props__.__dict__["suffix_index"] = suffix_index
            __props__.__dict__["tags"] = tags
            __props__.__dict__["unique_suffix"] = unique_suffix
            __props__.__dict__["user_data"] = user_data
            __props__.__dict__["version_description"] = version_description
            __props__.__dict__["volumes"] = volumes
            __props__.__dict__["vpc_id"] = vpc_id
            __props__.__dict__["zone_id"] = zone_id
            __props__.__dict__["version_number"] = None
        super(LaunchTemplateVersion, __self__).__init__(
            'bytepluscc:ecs/launchTemplateVersion:LaunchTemplateVersion',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            deployment_set_group_number: Optional[pulumi.Input[builtins.int]] = None,
            deployment_set_id: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            eip: Optional[pulumi.Input[Union['LaunchTemplateVersionEipArgs', 'LaunchTemplateVersionEipArgsDict']]] = None,
            host_name: Optional[pulumi.Input[builtins.str]] = None,
            hpc_cluster_id: Optional[pulumi.Input[builtins.str]] = None,
            image_id: Optional[pulumi.Input[builtins.str]] = None,
            image_name: Optional[pulumi.Input[builtins.str]] = None,
            instance_charge_type: Optional[pulumi.Input[builtins.str]] = None,
            instance_name: Optional[pulumi.Input[builtins.str]] = None,
            instance_type_id: Optional[pulumi.Input[builtins.str]] = None,
            keep_image_credential: Optional[pulumi.Input[builtins.bool]] = None,
            key_pair_name: Optional[pulumi.Input[builtins.str]] = None,
            launch_template_id: Optional[pulumi.Input[builtins.str]] = None,
            network_interfaces: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LaunchTemplateVersionNetworkInterfaceArgs', 'LaunchTemplateVersionNetworkInterfaceArgsDict']]]]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            scheduled_instance: Optional[pulumi.Input[Union['LaunchTemplateVersionScheduledInstanceArgs', 'LaunchTemplateVersionScheduledInstanceArgsDict']]] = None,
            security_enhancement_strategy: Optional[pulumi.Input[builtins.str]] = None,
            spot_price_limit: Optional[pulumi.Input[builtins.float]] = None,
            spot_strategy: Optional[pulumi.Input[builtins.str]] = None,
            suffix_index: Optional[pulumi.Input[builtins.int]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LaunchTemplateVersionTagArgs', 'LaunchTemplateVersionTagArgsDict']]]]] = None,
            unique_suffix: Optional[pulumi.Input[builtins.bool]] = None,
            user_data: Optional[pulumi.Input[builtins.str]] = None,
            version_description: Optional[pulumi.Input[builtins.str]] = None,
            version_number: Optional[pulumi.Input[builtins.str]] = None,
            volumes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LaunchTemplateVersionVolumeArgs', 'LaunchTemplateVersionVolumeArgsDict']]]]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None,
            zone_id: Optional[pulumi.Input[builtins.str]] = None) -> 'LaunchTemplateVersion':
        """
        Get an existing LaunchTemplateVersion resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] deployment_set_group_number: 当ECS实例要加入或调整的部署集策略为部署集组高可用策略（AvailabilityGroup）时，可以通过该参数指定实例在部署集中的分组号。
        :param pulumi.Input[builtins.str] deployment_set_id: 实例需要加入的部署集ID。
        :param pulumi.Input[builtins.str] description: 实例的描述。
        :param pulumi.Input[Union['LaunchTemplateVersionEipArgs', 'LaunchTemplateVersionEipArgsDict']] eip: 实例绑定的公网IP信息。
        :param pulumi.Input[builtins.str] host_name: 实例的主机名。Linux系统的主机名长度限制为2～59个字符。Windows系统的主机名长度限制为2～10个字符。
        :param pulumi.Input[builtins.str] hpc_cluster_id: 当创建高性能计算GPU型实例时，请指定高性能计算集群ID。
        :param pulumi.Input[builtins.str] image_id: 镜像ID。
        :param pulumi.Input[builtins.str] image_name: 镜像名称。
        :param pulumi.Input[builtins.str] instance_charge_type: 实例和云盘的计费类型，取值：PostPaid：按量计费。PrePaid：包年包月。Esi：弹性预约实例。Segmented：时段型弹性预约实例。
        :param pulumi.Input[builtins.str] instance_name: 实例的名称。
        :param pulumi.Input[builtins.str] instance_type_id: 实例的规格。
        :param pulumi.Input[builtins.bool] keep_image_credential: 是否保留镜像设置，取值：true：保留镜像设置，保留后将使用镜像预设的密码或密钥对登录实例。false（默认）：不保留镜像设置。
        :param pulumi.Input[builtins.str] key_pair_name: 实例绑定的密钥对。
        :param pulumi.Input[builtins.str] launch_template_id: 实例启动模板 ID。
        :param pulumi.Input[builtins.str] project_name: 实例所属项目。
        :param pulumi.Input[Union['LaunchTemplateVersionScheduledInstanceArgs', 'LaunchTemplateVersionScheduledInstanceArgsDict']] scheduled_instance: 弹性预约单信息。
        :param pulumi.Input[builtins.str] security_enhancement_strategy: 是否开启安全加固。Active:开启安全加固，仅对公共镜像生效。InActive:关闭安全加固，对所有镜像生效。
        :param pulumi.Input[builtins.float] spot_price_limit: 抢占式实例的每小时最高价格。
        :param pulumi.Input[builtins.str] spot_strategy: 按量计费的抢占式策略。取值：NoSpot：表示创建正常按量计费实例。SpotAsPriceGo：系统自动出价，跟随当前市场实际价格的抢占式实例。SpotWithPriceLimit：设置出价上限的抢占式实例。
        :param pulumi.Input[builtins.int] suffix_index: 有序后缀的起始序号。
        :param pulumi.Input[builtins.bool] unique_suffix: 表示当创建多台实例时，是否为Hostname和InstanceName自动添加有序后缀。
        :param pulumi.Input[builtins.str] user_data: 实例的自定义数据。
        :param pulumi.Input[builtins.str] version_description: 模版版本描述。
        :param pulumi.Input[builtins.str] version_number: 模板版本号。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络ID。
        :param pulumi.Input[builtins.str] zone_id: 实例所属可用区ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LaunchTemplateVersionState.__new__(_LaunchTemplateVersionState)

        __props__.__dict__["deployment_set_group_number"] = deployment_set_group_number
        __props__.__dict__["deployment_set_id"] = deployment_set_id
        __props__.__dict__["description"] = description
        __props__.__dict__["eip"] = eip
        __props__.__dict__["host_name"] = host_name
        __props__.__dict__["hpc_cluster_id"] = hpc_cluster_id
        __props__.__dict__["image_id"] = image_id
        __props__.__dict__["image_name"] = image_name
        __props__.__dict__["instance_charge_type"] = instance_charge_type
        __props__.__dict__["instance_name"] = instance_name
        __props__.__dict__["instance_type_id"] = instance_type_id
        __props__.__dict__["keep_image_credential"] = keep_image_credential
        __props__.__dict__["key_pair_name"] = key_pair_name
        __props__.__dict__["launch_template_id"] = launch_template_id
        __props__.__dict__["network_interfaces"] = network_interfaces
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["scheduled_instance"] = scheduled_instance
        __props__.__dict__["security_enhancement_strategy"] = security_enhancement_strategy
        __props__.__dict__["spot_price_limit"] = spot_price_limit
        __props__.__dict__["spot_strategy"] = spot_strategy
        __props__.__dict__["suffix_index"] = suffix_index
        __props__.__dict__["tags"] = tags
        __props__.__dict__["unique_suffix"] = unique_suffix
        __props__.__dict__["user_data"] = user_data
        __props__.__dict__["version_description"] = version_description
        __props__.__dict__["version_number"] = version_number
        __props__.__dict__["volumes"] = volumes
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["zone_id"] = zone_id
        return LaunchTemplateVersion(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="deploymentSetGroupNumber")
    def deployment_set_group_number(self) -> pulumi.Output[builtins.int]:
        """
        当ECS实例要加入或调整的部署集策略为部署集组高可用策略（AvailabilityGroup）时，可以通过该参数指定实例在部署集中的分组号。
        """
        return pulumi.get(self, "deployment_set_group_number")

    @property
    @pulumi.getter(name="deploymentSetId")
    def deployment_set_id(self) -> pulumi.Output[builtins.str]:
        """
        实例需要加入的部署集ID。
        """
        return pulumi.get(self, "deployment_set_id")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        实例的描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def eip(self) -> pulumi.Output['outputs.LaunchTemplateVersionEip']:
        """
        实例绑定的公网IP信息。
        """
        return pulumi.get(self, "eip")

    @property
    @pulumi.getter(name="hostName")
    def host_name(self) -> pulumi.Output[builtins.str]:
        """
        实例的主机名。Linux系统的主机名长度限制为2～59个字符。Windows系统的主机名长度限制为2～10个字符。
        """
        return pulumi.get(self, "host_name")

    @property
    @pulumi.getter(name="hpcClusterId")
    def hpc_cluster_id(self) -> pulumi.Output[builtins.str]:
        """
        当创建高性能计算GPU型实例时，请指定高性能计算集群ID。
        """
        return pulumi.get(self, "hpc_cluster_id")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> pulumi.Output[builtins.str]:
        """
        镜像ID。
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="imageName")
    def image_name(self) -> pulumi.Output[builtins.str]:
        """
        镜像名称。
        """
        return pulumi.get(self, "image_name")

    @property
    @pulumi.getter(name="instanceChargeType")
    def instance_charge_type(self) -> pulumi.Output[builtins.str]:
        """
        实例和云盘的计费类型，取值：PostPaid：按量计费。PrePaid：包年包月。Esi：弹性预约实例。Segmented：时段型弹性预约实例。
        """
        return pulumi.get(self, "instance_charge_type")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> pulumi.Output[builtins.str]:
        """
        实例的名称。
        """
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter(name="instanceTypeId")
    def instance_type_id(self) -> pulumi.Output[builtins.str]:
        """
        实例的规格。
        """
        return pulumi.get(self, "instance_type_id")

    @property
    @pulumi.getter(name="keepImageCredential")
    def keep_image_credential(self) -> pulumi.Output[builtins.bool]:
        """
        是否保留镜像设置，取值：true：保留镜像设置，保留后将使用镜像预设的密码或密钥对登录实例。false（默认）：不保留镜像设置。
        """
        return pulumi.get(self, "keep_image_credential")

    @property
    @pulumi.getter(name="keyPairName")
    def key_pair_name(self) -> pulumi.Output[builtins.str]:
        """
        实例绑定的密钥对。
        """
        return pulumi.get(self, "key_pair_name")

    @property
    @pulumi.getter(name="launchTemplateId")
    def launch_template_id(self) -> pulumi.Output[builtins.str]:
        """
        实例启动模板 ID。
        """
        return pulumi.get(self, "launch_template_id")

    @property
    @pulumi.getter(name="networkInterfaces")
    def network_interfaces(self) -> pulumi.Output[Sequence['outputs.LaunchTemplateVersionNetworkInterface']]:
        return pulumi.get(self, "network_interfaces")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        实例所属项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="scheduledInstance")
    def scheduled_instance(self) -> pulumi.Output['outputs.LaunchTemplateVersionScheduledInstance']:
        """
        弹性预约单信息。
        """
        return pulumi.get(self, "scheduled_instance")

    @property
    @pulumi.getter(name="securityEnhancementStrategy")
    def security_enhancement_strategy(self) -> pulumi.Output[builtins.str]:
        """
        是否开启安全加固。Active:开启安全加固，仅对公共镜像生效。InActive:关闭安全加固，对所有镜像生效。
        """
        return pulumi.get(self, "security_enhancement_strategy")

    @property
    @pulumi.getter(name="spotPriceLimit")
    def spot_price_limit(self) -> pulumi.Output[builtins.float]:
        """
        抢占式实例的每小时最高价格。
        """
        return pulumi.get(self, "spot_price_limit")

    @property
    @pulumi.getter(name="spotStrategy")
    def spot_strategy(self) -> pulumi.Output[builtins.str]:
        """
        按量计费的抢占式策略。取值：NoSpot：表示创建正常按量计费实例。SpotAsPriceGo：系统自动出价，跟随当前市场实际价格的抢占式实例。SpotWithPriceLimit：设置出价上限的抢占式实例。
        """
        return pulumi.get(self, "spot_strategy")

    @property
    @pulumi.getter(name="suffixIndex")
    def suffix_index(self) -> pulumi.Output[builtins.int]:
        """
        有序后缀的起始序号。
        """
        return pulumi.get(self, "suffix_index")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.LaunchTemplateVersionTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="uniqueSuffix")
    def unique_suffix(self) -> pulumi.Output[builtins.bool]:
        """
        表示当创建多台实例时，是否为Hostname和InstanceName自动添加有序后缀。
        """
        return pulumi.get(self, "unique_suffix")

    @property
    @pulumi.getter(name="userData")
    def user_data(self) -> pulumi.Output[builtins.str]:
        """
        实例的自定义数据。
        """
        return pulumi.get(self, "user_data")

    @property
    @pulumi.getter(name="versionDescription")
    def version_description(self) -> pulumi.Output[builtins.str]:
        """
        模版版本描述。
        """
        return pulumi.get(self, "version_description")

    @property
    @pulumi.getter(name="versionNumber")
    def version_number(self) -> pulumi.Output[builtins.str]:
        """
        模板版本号。
        """
        return pulumi.get(self, "version_number")

    @property
    @pulumi.getter
    def volumes(self) -> pulumi.Output[Sequence['outputs.LaunchTemplateVersionVolume']]:
        return pulumi.get(self, "volumes")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        私有网络ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Output[builtins.str]:
        """
        实例所属可用区ID。
        """
        return pulumi.get(self, "zone_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetAccountResult',
    'AwaitableGetAccountResult',
    'get_account',
    'get_account_output',
]

@pulumi.output_type
class GetAccountResult:
    """
    A collection of values returned by getAccount.
    """
    def __init__(__self__, account_id=None, account_name=None, allow_console=None, allow_exit=None, created_time=None, delete_uk=None, deleted_time=None, description=None, iam_role=None, id=None, is_owner=None, join_type=None, main_name=None, member_account_id=None, org_id=None, org_type=None, org_unit_id=None, org_unit_name=None, org_verification_id=None, owner=None, password=None, secure_contact_info=None, show_name=None, tags=None, updated_time=None, verification_relation_id=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if account_name and not isinstance(account_name, str):
            raise TypeError("Expected argument 'account_name' to be a str")
        pulumi.set(__self__, "account_name", account_name)
        if allow_console and not isinstance(allow_console, int):
            raise TypeError("Expected argument 'allow_console' to be a int")
        pulumi.set(__self__, "allow_console", allow_console)
        if allow_exit and not isinstance(allow_exit, int):
            raise TypeError("Expected argument 'allow_exit' to be a int")
        pulumi.set(__self__, "allow_exit", allow_exit)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if delete_uk and not isinstance(delete_uk, str):
            raise TypeError("Expected argument 'delete_uk' to be a str")
        pulumi.set(__self__, "delete_uk", delete_uk)
        if deleted_time and not isinstance(deleted_time, str):
            raise TypeError("Expected argument 'deleted_time' to be a str")
        pulumi.set(__self__, "deleted_time", deleted_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if iam_role and not isinstance(iam_role, str):
            raise TypeError("Expected argument 'iam_role' to be a str")
        pulumi.set(__self__, "iam_role", iam_role)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_owner and not isinstance(is_owner, int):
            raise TypeError("Expected argument 'is_owner' to be a int")
        pulumi.set(__self__, "is_owner", is_owner)
        if join_type and not isinstance(join_type, int):
            raise TypeError("Expected argument 'join_type' to be a int")
        pulumi.set(__self__, "join_type", join_type)
        if main_name and not isinstance(main_name, str):
            raise TypeError("Expected argument 'main_name' to be a str")
        pulumi.set(__self__, "main_name", main_name)
        if member_account_id and not isinstance(member_account_id, str):
            raise TypeError("Expected argument 'member_account_id' to be a str")
        pulumi.set(__self__, "member_account_id", member_account_id)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if org_type and not isinstance(org_type, int):
            raise TypeError("Expected argument 'org_type' to be a int")
        pulumi.set(__self__, "org_type", org_type)
        if org_unit_id and not isinstance(org_unit_id, str):
            raise TypeError("Expected argument 'org_unit_id' to be a str")
        pulumi.set(__self__, "org_unit_id", org_unit_id)
        if org_unit_name and not isinstance(org_unit_name, str):
            raise TypeError("Expected argument 'org_unit_name' to be a str")
        pulumi.set(__self__, "org_unit_name", org_unit_name)
        if org_verification_id and not isinstance(org_verification_id, str):
            raise TypeError("Expected argument 'org_verification_id' to be a str")
        pulumi.set(__self__, "org_verification_id", org_verification_id)
        if owner and not isinstance(owner, str):
            raise TypeError("Expected argument 'owner' to be a str")
        pulumi.set(__self__, "owner", owner)
        if password and not isinstance(password, str):
            raise TypeError("Expected argument 'password' to be a str")
        pulumi.set(__self__, "password", password)
        if secure_contact_info and not isinstance(secure_contact_info, dict):
            raise TypeError("Expected argument 'secure_contact_info' to be a dict")
        pulumi.set(__self__, "secure_contact_info", secure_contact_info)
        if show_name and not isinstance(show_name, str):
            raise TypeError("Expected argument 'show_name' to be a str")
        pulumi.set(__self__, "show_name", show_name)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)
        if verification_relation_id and not isinstance(verification_relation_id, str):
            raise TypeError("Expected argument 'verification_relation_id' to be a str")
        pulumi.set(__self__, "verification_relation_id", verification_relation_id)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> builtins.str:
        """
        火山账号ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> builtins.str:
        """
        账户名称。5-20个字符。
        """
        return pulumi.get(self, "account_name")

    @property
    @pulumi.getter(name="allowConsole")
    def allow_console(self) -> builtins.int:
        """
        允许控制台访问，1: 允许，2: 不允许。
        """
        return pulumi.get(self, "allow_console")

    @property
    @pulumi.getter(name="allowExit")
    def allow_exit(self) -> builtins.int:
        """
        允许退出，1: 允许，2: 不允许。
        """
        return pulumi.get(self, "allow_exit")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="deleteUk")
    def delete_uk(self) -> builtins.str:
        """
        删除标记。
        """
        return pulumi.get(self, "delete_uk")

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> builtins.str:
        """
        删除时间。
        """
        return pulumi.get(self, "deleted_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="iamRole")
    def iam_role(self) -> builtins.str:
        """
        IAM角色名称。
        """
        return pulumi.get(self, "iam_role")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isOwner")
    def is_owner(self) -> builtins.int:
        """
        是否是管理员，0.非管理员，1.管理员。
        """
        return pulumi.get(self, "is_owner")

    @property
    @pulumi.getter(name="joinType")
    def join_type(self) -> builtins.int:
        """
        加入类型，1: 创建，2: 邀请。
        """
        return pulumi.get(self, "join_type")

    @property
    @pulumi.getter(name="mainName")
    def main_name(self) -> builtins.str:
        """
        主体名称。
        """
        return pulumi.get(self, "main_name")

    @property
    @pulumi.getter(name="memberAccountId")
    def member_account_id(self) -> builtins.str:
        """
        组织成员账号ID。
        """
        return pulumi.get(self, "member_account_id")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> builtins.str:
        """
        组织ID。
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter(name="orgType")
    def org_type(self) -> builtins.int:
        """
        组织类型，1.企业组织。
        """
        return pulumi.get(self, "org_type")

    @property
    @pulumi.getter(name="orgUnitId")
    def org_unit_id(self) -> builtins.str:
        """
        组织单元ID。传入 0 加入到 root 单元。
        """
        return pulumi.get(self, "org_unit_id")

    @property
    @pulumi.getter(name="orgUnitName")
    def org_unit_name(self) -> builtins.str:
        """
        组织单元名称。
        """
        return pulumi.get(self, "org_unit_name")

    @property
    @pulumi.getter(name="orgVerificationId")
    def org_verification_id(self) -> builtins.str:
        """
        认证主体ID。
        """
        return pulumi.get(self, "org_verification_id")

    @property
    @pulumi.getter
    def owner(self) -> builtins.str:
        """
        管理员ID。
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter
    def password(self) -> builtins.str:
        """
        账户密码。
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="secureContactInfo")
    def secure_contact_info(self) -> 'outputs.GetAccountSecureContactInfoResult':
        """
        安全联系信息。
        """
        return pulumi.get(self, "secure_contact_info")

    @property
    @pulumi.getter(name="showName")
    def show_name(self) -> builtins.str:
        """
        显示名称。
        """
        return pulumi.get(self, "show_name")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetAccountTagResult']:
        """
        标签列表。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="verificationRelationId")
    def verification_relation_id(self) -> builtins.str:
        """
        被继承认证主体的账号ID，给非管理员认证主体创建账号时需要，账号需已加入企业组织。默认不传，则继承企业组织管理员的认证主体。
        """
        return pulumi.get(self, "verification_relation_id")


class AwaitableGetAccountResult(GetAccountResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAccountResult(
            account_id=self.account_id,
            account_name=self.account_name,
            allow_console=self.allow_console,
            allow_exit=self.allow_exit,
            created_time=self.created_time,
            delete_uk=self.delete_uk,
            deleted_time=self.deleted_time,
            description=self.description,
            iam_role=self.iam_role,
            id=self.id,
            is_owner=self.is_owner,
            join_type=self.join_type,
            main_name=self.main_name,
            member_account_id=self.member_account_id,
            org_id=self.org_id,
            org_type=self.org_type,
            org_unit_id=self.org_unit_id,
            org_unit_name=self.org_unit_name,
            org_verification_id=self.org_verification_id,
            owner=self.owner,
            password=self.password,
            secure_contact_info=self.secure_contact_info,
            show_name=self.show_name,
            tags=self.tags,
            updated_time=self.updated_time,
            verification_relation_id=self.verification_relation_id)


def get_account(id: Optional[builtins.str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAccountResult:
    """
    Data Source schema for Byteplus::Organization::Account


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:organization/getAccount:getAccount', __args__, opts=opts, typ=GetAccountResult).value

    return AwaitableGetAccountResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        account_name=pulumi.get(__ret__, 'account_name'),
        allow_console=pulumi.get(__ret__, 'allow_console'),
        allow_exit=pulumi.get(__ret__, 'allow_exit'),
        created_time=pulumi.get(__ret__, 'created_time'),
        delete_uk=pulumi.get(__ret__, 'delete_uk'),
        deleted_time=pulumi.get(__ret__, 'deleted_time'),
        description=pulumi.get(__ret__, 'description'),
        iam_role=pulumi.get(__ret__, 'iam_role'),
        id=pulumi.get(__ret__, 'id'),
        is_owner=pulumi.get(__ret__, 'is_owner'),
        join_type=pulumi.get(__ret__, 'join_type'),
        main_name=pulumi.get(__ret__, 'main_name'),
        member_account_id=pulumi.get(__ret__, 'member_account_id'),
        org_id=pulumi.get(__ret__, 'org_id'),
        org_type=pulumi.get(__ret__, 'org_type'),
        org_unit_id=pulumi.get(__ret__, 'org_unit_id'),
        org_unit_name=pulumi.get(__ret__, 'org_unit_name'),
        org_verification_id=pulumi.get(__ret__, 'org_verification_id'),
        owner=pulumi.get(__ret__, 'owner'),
        password=pulumi.get(__ret__, 'password'),
        secure_contact_info=pulumi.get(__ret__, 'secure_contact_info'),
        show_name=pulumi.get(__ret__, 'show_name'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_time=pulumi.get(__ret__, 'updated_time'),
        verification_relation_id=pulumi.get(__ret__, 'verification_relation_id'))
def get_account_output(id: Optional[pulumi.Input[builtins.str]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAccountResult]:
    """
    Data Source schema for Byteplus::Organization::Account


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:organization/getAccount:getAccount', __args__, opts=opts, typ=GetAccountResult)
    return __ret__.apply(lambda __response__: GetAccountResult(
        account_id=pulumi.get(__response__, 'account_id'),
        account_name=pulumi.get(__response__, 'account_name'),
        allow_console=pulumi.get(__response__, 'allow_console'),
        allow_exit=pulumi.get(__response__, 'allow_exit'),
        created_time=pulumi.get(__response__, 'created_time'),
        delete_uk=pulumi.get(__response__, 'delete_uk'),
        deleted_time=pulumi.get(__response__, 'deleted_time'),
        description=pulumi.get(__response__, 'description'),
        iam_role=pulumi.get(__response__, 'iam_role'),
        id=pulumi.get(__response__, 'id'),
        is_owner=pulumi.get(__response__, 'is_owner'),
        join_type=pulumi.get(__response__, 'join_type'),
        main_name=pulumi.get(__response__, 'main_name'),
        member_account_id=pulumi.get(__response__, 'member_account_id'),
        org_id=pulumi.get(__response__, 'org_id'),
        org_type=pulumi.get(__response__, 'org_type'),
        org_unit_id=pulumi.get(__response__, 'org_unit_id'),
        org_unit_name=pulumi.get(__response__, 'org_unit_name'),
        org_verification_id=pulumi.get(__response__, 'org_verification_id'),
        owner=pulumi.get(__response__, 'owner'),
        password=pulumi.get(__response__, 'password'),
        secure_contact_info=pulumi.get(__response__, 'secure_contact_info'),
        show_name=pulumi.get(__response__, 'show_name'),
        tags=pulumi.get(__response__, 'tags'),
        updated_time=pulumi.get(__response__, 'updated_time'),
        verification_relation_id=pulumi.get(__response__, 'verification_relation_id')))
